#
# hci.py
#
# Copyright (c) 2018 Virtuozzo International GmbH. All rights reserved.
#
# This file is part of OpenVZ. OpenVZ is free software;
# you can redistribute it and/or modify it under the terms of the GNU
# Lesser General Public License as published by the Free Software Foundation;
# either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.

from pyanaconda.i18n import N_
from pyanaconda.product import productName
from blivet.size import Size
from distutils.sysconfig import get_python_lib
import sys

sys.path.insert(0,"%s/pyanaconda/installclasses" % get_python_lib(plat_specific=1))

from virtuozzo import VirtuozzoBaseInstallClass

class VzHCIBaseInstallClass(VirtuozzoBaseInstallClass):
    vendor = "Virtuozzo"
    name = N_("%s Infrastructure Platform" % vendor)
    hidden = False
    if productName != "%s Infrastructure Platform" % vendor:
        hidden = True

    def __init__(self):
        VirtuozzoBaseInstallClass.__init__(self)
        self.is_vz = False
        self.with_va = False
        self.create_bridges = False
        self.fix_ifcfgs = True
        self.select_minsize_slash = False
        self.slash_size = Size("20GiB")
        # 0 means default value - see blivet sources
        self.max_slash_size = 0
        self.mask_nm = True
        self.docker_img_ver = "4.0.3"
        self.not_ask_reboot = True

    @property
    def min_hdd_size(self):
        return self.swap_size + self.slash_size

    @property
    def get_eula(self):
        return "/usr/share/licenses/hci-release/EULA"

    @property
    def get_release_f(self):
        return "/etc/hci-release"
